/*
 *
 Project name:
       UNI Hall Click
 Copyright:
      (c) mikroElektronika, 2014.
 Revision History:
      20140820:
      - Initial release (RD);
 Description:
      UUNI HALL click is a simple solution for adding an unipolar Hall switch to
      your design. It carries the Melexis US5881 unipolar Hall-effect switch and
      a 74LVC1T45 single bit, dual supply translating transceiver. UNI HALL click
      communicates with the target board through the mikroBUS INT line. The
      board is designed to use either a 3.3V or 5V power supply (which also defines the
      logic level of the output signal).
      The unipolar Hall effect sensor on UNI HALL click is sensitive to north pole magnetic
      fieldswhen exposed to such a field, it outputs a LOW logic level. Othewise the
      output is a HIGH logic level. In its simplest application, UNI HALL click
      can be employed as part of a long lasting contactless proximity switch.
      However, magnets can be employed in various ways to infer the speed,
      position, or other properties of an object; there are countless ways to utilize
      UNI HALL click in your design.

 Test configuration:
     MCU:             PIC18F45K22
                      http://ww1.microchip.com/downloads/en/DeviceDoc/41412F.pdf
     Dev. Board:      EasyPIC v7 Connectivity
                      http://www.mikroe.com/easypic/
     Oscillator:      HS-PLL, 8MHz Crystal, 32MHz MCU Clock
     ext. modules:    UNI Hall Click
                      http://www.mikroe.com/click/uni-hall/
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
 NOTES:
      - Place UNI Hall Click board in the mikroBUS socket 1.
      - Set development board J5 jumper according to SMD jumper on click board. By default it's soldered in the 3.3V position.
      - Turn On SW3-2 and SW3-4 switches for PORTB and PORTD LEDs.

*/

char cnt, old_cnt;
char txt[10];

void interrupt() {
  if(INT0IF_bit) {
    cnt++;
    INT0IF_bit = 0;
  }
}

void main() {
   ANSELB  = 0;                // Configure portB pins as digital
   ANSELD  = 0;                // Configure portD pins as digital
   TRISB   = 0x01;             // Configure RB0 pin as input
   TRISD   = 0;                // Configure portD pins as output
   LATB    = 0x00;             // Reset PortB
   LATD    = 0;                // Reset PortD
   cnt     = 0;
   old_cnt = cnt;

   //IPEN_bit = 1;
   INT0IE_bit  = 1;            // Enable interrupts on RB0
   INTEDG0_bit = 0;            // Interrupt on falling age
   GIE_bit     = 1;
   PEIE_bit    = 1;
   //INT0IE_bit = 1;
   
   while(1) {
      if (old_cnt != cnt) {
         PORTD = cnt;
         old_cnt = cnt;
      }
   }
}